pub async fn get_verify_stats(
connection: &Connection,
allowlist: &HashSet<String>,
blocklist: &HashSet<String>,
) -> Result<VerifyStats, MonitordVerifyError>Expand description
Collect verification stats for all units in the system
pub async fn get_verify_stats(
connection: &Connection,
allowlist: &HashSet<String>,
blocklist: &HashSet<String>,
) -> Result<VerifyStats, MonitordVerifyError>Collect verification stats for all units in the system